package SrvMngr::I18N::Modules::Ddclient::en;
use strict;
use warnings;
use utf8;
use Mojo::Base 'SrvMngr::I18N';

use SrvMngr::I18N::Modules::General::en;

my %lexicon = (
'FORM_TITLE' => 'Create, remove or change the publication of virtual domains',
'Params_for_IP_Retrieval'=>' Parameters to control how the IP of your server is found:',
'DESCRIPTION'=> 'Use this contrib when you have a sme server connected to a ISP service using a dynamic IP, and you wish to host multiple domains.
<br>ddclient is a client for updating dynamic DNS entries for domains hosted at different DNS providers.
<br>Configure your dynamic host domains via the ddclient server manager panel.
<br>ddclient can be used on servers configured in server gateway mode or in server only mode.<br>
SmeServer documentation:<a href="https://wiki.contribs.org/Ddclient">https://wiki.contribs.org/Ddclient</a>',
'FORM_DESCRIPTION' => 'Virtual Domains for publication on the net:',
'NO_VIRTUAL_DOMAINS' => 'There are no virtual domains in the system.',
'CURRENT_LIST_OF_DOMAINS' => 'Current list of virtual domains',
'PUBLICATION' => 'Publication',
'PRIMARY_SITE' => 'Primary Site',
'CONTENT' => '[_1] i-bay',
'CREATE_TITLE' => 'Create a new publication virtual domain',
'SERVERS_LABEL' => 'Where to publish',
'MX' => 'record MX',
'NAME_LABEL' => 'Login to publish',
'PASSWORD_LABEL' => 'Password to publish',
'CONTENT_FIELD_DESCRIPTION' => 'For the web site, you may choose your primary web site or any i-bay as the content.',
'DOMAIN_NAME_VALIDATION_ERROR' => 'Error: unexpected or missing characters in domain name [_1].  The domain name should contain one or more letters, numbers, periods and minus signs.  Did not create new domain.',
'DOMAIN_DESCRIPTION_VALIDATION_ERROR' => 'Error: unexpected or missing characters in domain description [_1].  Did not create new domain.',
'DOMAIN_IN_USE_ERROR' => 'Error: domain [_1] is already in use.  Did not create  new domain.',
'DOMAIN_LOGIN_VALIDATION_ERROR'=> 'Domain login must not be blank and only consist of letter, numbers, "." or "@"',
'RESERVED_SECURE_DOMAIN_ERROR' => 'Error: domain [_1] is reserved to provide a secured webserver for the virtual domain [_2].  Did not create new domain.',
'SYSTEM_DOMAIN_ERROR' => 'Error: domain [_1] is your system domain name.  You cannot have a virtual domain with the same name.  Did not create new domain.',
'RESERVED_SECURE_SYSTEM_DOMAIN_ERROR' => 'Error: domain [_1] is reserved to provide a secured webserver for your system domain name [_2].  Did not create new domain.',
'SUCCESSFULLY_CREATED' => 'Successfully publication domain [_1] on [_2].',
'MODIFY_TITLE' => 'Modify virtual domain',
'NONEXISTENT_DOMAIN_ERROR' => 'Error: [_1] is not an existing domain.',
'SUCCESSFULLY_MODIFIED' => 'Successfully modified the publication [_1] on [_2].',
'REMOVE_TITLE' => 'Remove publication of virtual domain',
'REMOVE_DESCRIPTION' => '<p>You are about to remove the publication of domain [_1] ([_2]) on [_3].  
</p>
<p>
<b>Are you sure you wish to remove this domain\'s publication ?</b>
</p>
',
'ERROR_WHILE_REMOVING_DOMAIN' => 'Error: internal failure while removing publication of [_1].',
'SUCCESSFULLY_DELETED' => 'Successfully deleted publication of [_1] on [_2].',

# Service descriptions
'DYNDNS1' => 'dyndns.org dynamic addresses',
'DYNDNS2' => 'dyndns.org static addresses',
'DYNDNS3' => 'dyndns.org custom addresses',
'ZONEDIT' => 'ZoneEdit (zoneedit.com)',
'EASYDNS' => 'EasyDNS (easydns.com)',
'HAMMER' => 'Hammernode (hn.org) dynamic addresses',
'DSLREPORTS' => 'dslreports.com dynamic-host monitoring',
'EURODYNDNS' => 'eurodyndns.org dynamic addresses',
'DTDNS' => 'DtDNS (www.dtdns.com) dynamic addresses',
'LOOPIA' => 'Loopia (loopia.se) dynamic addresses',
'DNSPARK' => ' Dnspark (dnspark.com) dynamic addresses',
'DYNHOST' => ' DynHost (ovh.com) dynamic addresses',
'NOIP' => ' NoIP (noip.com) dynamic addresses',
'CHANGEIP' => ' ChangeIP (changeip.com) dynamic addresses',
'NAMECHEAP' => ' NAMECHEAP (namecheap.com) dynamic addresses',
'SPDNS' => ' SPDNS (spdns.de) dynamic addresses',
'SITELUTIONS'=>'SITELUTIONS sitelutions.com dynamic addresses',
'FREEDNS'=>'FREEDNS freedns.afraid.org for details',
'NSUPDATE'=>'NSUPDATE See nsupdate(1) and ddns-confgen(8) for details ',
'CLOUDFLARE'=>'CLOUDFLARE www.cloudflare.com/ for details',
'GOOGLEDOMAINS'=>'GOOGLEDOMAINS www.google.com/domains for details',
'DUCKDNS'=>'DUCKDNS duckdns.org for details',
'FREEMYIP'=>'FREEMYIP freemyip.com for details',
'WOIMA'=>'WOIMA woima.fi for details',
'YANDEX'=>'YANDEX domain.yandex.com for details',
'DNSMADEEASY'=>'DNSMADEEASY dnsmadeeasy.com for details',
'DONDOMINIO'=>'DONDOMINIO www.dondominio.com for details',
'NEARLYFREESPEECH'=>'NFSN www.nearlyfreespeech.net/services/dns for details',
'OVH'=>'OVH www.ovh.com for details',
'CLOUDNS'=>'CLOUDNS www.cloudns.net',
# End of Service descriptions

# v3.11.x Service descriptions:
"1984" => "1984-https://kb.1984hosting.com/doku.php?id=freedns",
"changeip" => "changeip-https://changeip.com",
"cloudflare" => "cloudflare-https://cloudflare.com",
"cloudns" => "cloudns-https://cloudns.com",
"digitalocean" => "digitalocean-https://digitalocean.com",
"dinahosting" => "dinahosting-https://dinahosting.com",
"dnsexit" => "dnsexit-https://dnsexit.com/",
"dnsmadeeasy" => "dnsmadeeasy-https://dnsmadeeasy.com",
"domeneshop" => "domeneshop-https://domeneshop.com",
"dondominio" => "dondominio-https://dondominio.com",
"dslreports" => "dslreports-https://www.dslreports.com/",
"duckdns" => "duckdns-https://duckdns.com",
"dyndns1" => "dyndns1-https://account.dyn.com/",
"dyndns2" => "dyndns2-https://account.dyn.com/",
"easydns" => "easydns-https://easydns.com",
"enom" => "enom-https://enom.com",
"freedns" => "freedns-http://freedns.com",
"freemyip" => "freemyip-https://freemyip.com",
"gandi" => "gandi-https://gandi.com",
"godaddy" => "godaddy-https://godaddy.com",
"googledomains" => "googledomains-https://googledomains.com",
"hetzner" => "hetzner-https://hetzner.com",
"infomaniak" => "infomaniak-https://infomaniak.com",
"keysystems" => "keysystems-https://keysystems.com",
"mythicdyn" => "mythicdyn-https://www.mythic-beasts.com/support/api/dnsv2/dynamic-dns",
"namecheap" => "namecheap-https://namecheap.com",
"nfsn" => "nfsn-http://nfsn.com",
"njalla" => "njalla-https://njalla.com",
"noip" => "noip-https://noip.com",
"nsupdate" => "nsupdate-http://nsupdate.com",
"ovh" => "ovh-https://ovh.com",
"porkbun" => "porkbun-https://porkbun.com",
"regfishde" => "regfishde-regfishde",
"sitelutions" => "sitelutions-https://sitelutions.com",
"woima" => "woima-http://woima.com",
"yandex" => "yandex-https://yandex.com",
"zoneedit" => "zoneedit-https://www.zoneedit.com/dynamic-dns/",
# end of v3.11.x Service descriptions:

'MODIFY_DESCRIPTION' => "You can modify the Dynamic DNS Service that you use and change the username and password",
'CREATE_DESCRIPTION' => "You can create a domain to use for the Dynamic DNS Service that you use and set or change the username and password",
'CUSTOMDNS' => 'Custom Dynamic DNS Provider',
'CUSTOMDNS_LABEL' => 'Custom server Address',
'CUSTOM_PROTOCOL_LABEL' => 'Custom ddclient Protocol',
'CUSTOM_DESCRIPTION' => 'You can use a custom dynamic dns provider if yours is not in the published list. Please fill the custom fields with the appropriate settings',
'CUSTOMDNS_VALIDATION_ERROR' => 'Error: unexpected or missing characters in custom server address field of domain  [_1].  The server address should contain one or more letters, numbers, periods and minus signs.  Did not apply the change.',
'ddclient' =>'Dynamic Clients',
'DOMAIN_NAME_ALREADY_EXIST' => 'Error: this domain:"[_1]" already exists. Please chose another.',
'FREE_FORM_DESCRIPTION' => 'Here you can create any domain name to publish over the net:',
'RETRIEVE_SSL' => 'SSL update',
'RETRIEVE_DEAMONUPDATE' => 'Deamon update (seconds)',
'RETRIEVE_URLCHECKIP' => 'Url for the external IP',
'APPLY' => 'Save',
'DOMAIN_NAME_LABEL' => 'Domain Name',
'DESCRIPTION_LABEL' => 'Domain description',
'SUCCESSFULLY_MODIFIED_RETRIEVE_IP' => 'You have successfully modified the retrieve IP options.',
'RETRIEVE_METHOD' => 'Method to retrieve new IP:',
'RETRIEVE_IF' => 'Local interface to get new IP',
'RETRIEVE_CMD' => 'Command to execute to get IP',
'SME external Interface' => 'SME external interface',
'SME configuration DB' => 'SME configuration DB',
'web' => 'Web query',
'Interface' => 'IP from interface',
'IP' => 'Manual IP setting',
'Command' => 'Command to execute',
'RETRIEVE_IP' => 'IP to manually force'
);

our %Lexicon = (
	%{ SrvMngr::I18N::Modules::General::en::Lexicon },
	%lexicon
);


1;
